UIC=uic
MV=mv
$UIC -o AudioDialogData.h AudioDialog.ui
$UIC -i AudioDialogData.h -o AudioDialogData.cpp AudioDialog.ui
$UIC -o EmuDialogData.h EmuDialog.ui
$UIC -i EmuDialogData.h -o EmuDialogData.cpp EmuDialog.ui
$UIC -o FilterDialogData.h FilterDialog.ui
$UIC -i FilterDialogData.h -o FilterDialogData.cpp FilterDialog.ui
$UIC -o HistoryDialogData.h HistoryDialog.ui
$UIC -i HistoryDialogData.h -o HistoryDialogData.cpp HistoryDialog.ui
$UIC -o HVSC_DialogData.h HVSC_Dialog.ui
$UIC -i HVSC_DialogData.h -o HVSC_DialogData.cpp HVSC_Dialog.ui
$UIC -o MainDialogData.h MainDialog.ui
$UIC -i MainDialogData.h -o MainDialogData.cpp MainDialog.ui
$UIC -o MixerDialogData.h MixerDialog.ui
$UIC -i MixerDialogData.h -o MixerDialogData.cpp MixerDialog.ui
$UIC -o PlaylistDialogData.h PlaylistDialog.ui
$UIC -i PlaylistDialogData.h -o PlaylistDialogData.cpp PlaylistDialog.ui
$UIC -o PlaylistEditDialogData.h PlaylistEditDialog.ui
$UIC -i PlaylistEditDialogData.h -o PlaylistEditDialogData.cpp PlaylistEditDialog.ui
$UIC -o PlaylistOptDialog.h PlaylistOptDialog.ui
$UIC -i PlaylistOptDialog.h -o PlaylistOptDialog.cpp PlaylistOptDialog.ui
$UIC -o PlaylistUpdateDialog.h PlaylistUpdateDialog.ui
$UIC -i PlaylistUpdateDialog.h -o PlaylistUpdateDialog.cpp PlaylistUpdateDialog.ui
$UIC -o TSID2DialogData.h TSID2Dialog.ui
$UIC -i TSID2DialogData.h -o TSID2DialogData.cpp TSID2Dialog.ui
$UIC -o SidIdDialogData.h SidIdDialog.ui
$UIC -i SidIdDialogData.h -o SidIdDialogData.cpp SidIdDialog.ui
$MV -f *.h ..
$MV -f *.cpp ..
